@@ -51,7 +51,7 @@
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtcore_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <QtHelp/qhelpengine.h>
 #include <QtHelp/qhelpfilterengine.h>
 #include <QtHelp/qhelpsearchquerywidget.h>
@@ -61,7 +61,9 @@
 #include <QtHelp/qhelpfilterdata.h>
 #include <QtHelp/qhelpindexwidget.h>
 #include <QtHelp/qhelpsearchresultwidget.h>
+#include <QtHelp/qhelpfiltersettingswidget.h>
 #include <QtHelp/qhelpsearchengine.h>
+#include <QtHelp/qhelplink.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
@@ -90,15 +92,17 @@ enum : int {
     SBK_QHELPENGINECORE_IDX                                  = 5,
     SBK_QHELPFILTERDATA_IDX                                  = 6,
     SBK_QHELPFILTERENGINE_IDX                                = 7,
-    SBK_QHELPINDEXMODEL_IDX                                  = 8,
-    SBK_QHELPINDEXWIDGET_IDX                                 = 9,
-    SBK_QHELPSEARCHENGINE_IDX                                = 10,
-    SBK_QHELPSEARCHQUERY_IDX                                 = 11,
-    SBK_QHELPSEARCHQUERY_FIELDNAME_IDX                       = 12,
-    SBK_QHELPSEARCHQUERYWIDGET_IDX                           = 13,
-    SBK_QHELPSEARCHRESULT_IDX                                = 14,
-    SBK_QHELPSEARCHRESULTWIDGET_IDX                          = 15,
-    SBK_QtHelp_IDX_COUNT                                     = 16
+    SBK_QHELPFILTERSETTINGSWIDGET_IDX                        = 8,
+    SBK_QHELPINDEXMODEL_IDX                                  = 9,
+    SBK_QHELPINDEXWIDGET_IDX                                 = 10,
+    SBK_QHELPLINK_IDX                                        = 11,
+    SBK_QHELPSEARCHENGINE_IDX                                = 12,
+    SBK_QHELPSEARCHQUERY_FIELDNAME_IDX                       = 14,
+    SBK_QHELPSEARCHQUERY_IDX                                 = 13,
+    SBK_QHELPSEARCHQUERYWIDGET_IDX                           = 15,
+    SBK_QHELPSEARCHRESULT_IDX                                = 16,
+    SBK_QHELPSEARCHRESULTWIDGET_IDX                          = 17,
+    SBK_QtHelp_IDX_COUNT                                     = 18
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide2_QtHelpTypes;
@@ -111,20 +115,20 @@ extern SbkConverter **SbkPySide2_QtHelpTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTHELP_QLIST_QOBJECTPTR_IDX                          = 0, // const QList<QObject* > &
-    SBK_QTHELP_QVECTOR_INT_IDX                               = 1, // const QVector<int > &
-    SBK_QTHELP_QHASH_INT_QBYTEARRAY_IDX                      = 2, // const QHash<int,QByteArray > &
-    SBK_QTHELP_QLIST_QBYTEARRAY_IDX                          = 3, // QList<QByteArray >
-    SBK_QTHELP_QMAP_INT_QVARIANT_IDX                         = 4, // QMap<int,QVariant >
-    SBK_QTHELP_QLIST_QPERSISTENTMODELINDEX_IDX               = 5, // const QList<QPersistentModelIndex > &
-    SBK_QTHELP_QLIST_QACTIONPTR_IDX                          = 6, // QList<QAction* >
-    SBK_QTHELP_QLIST_QWIDGETPTR_IDX                          = 7, // QList<QWidget* >
-    SBK_QTHELP_QLIST_QURL_IDX                                = 8, // QList<QUrl >
-    SBK_QTHELP_QLIST_QSTRINGLIST_IDX                         = 9, // QList<QStringList >
-    SBK_QTHELP_QMAP_QSTRING_QURL_IDX                         = 10, // QMap<QString,QUrl >
-    SBK_QTHELP_QLIST_QVERSIONNUMBER_IDX                      = 11, // const QList<QVersionNumber > &
-    SBK_QTHELP_QMAP_QSTRING_QSTRING_IDX                      = 12, // QMap<QString,QString >
-    SBK_QTHELP_QMAP_QSTRING_QVERSIONNUMBER_IDX               = 13, // QMap<QString,QVersionNumber >
+    SBK_QTHELP_QVECTOR_INT_IDX                               = 0, // const QVector<int > &
+    SBK_QTHELP_QHASH_INT_QBYTEARRAY_IDX                      = 1, // const QHash<int,QByteArray > &
+    SBK_QTHELP_QMAP_INT_QVARIANT_IDX                         = 2, // QMap<int,QVariant >
+    SBK_QTHELP_QLIST_QPERSISTENTMODELINDEX_IDX               = 3, // const QList<QPersistentModelIndex > &
+    SBK_QTHELP_QLIST_QHELPLINK_IDX                           = 4, // QList<QHelpLink >
+    SBK_QTHELP_QLIST_QURL_IDX                                = 5, // QList<QUrl >
+    SBK_QTHELP_QLIST_QSTRINGLIST_IDX                         = 6, // QList<QStringList >
+    SBK_QTHELP_QMAP_QSTRING_QURL_IDX                         = 7, // QMap<QString,QUrl >
+    SBK_QTHELP_QLIST_QOBJECTPTR_IDX                          = 8, // const QList<QObject* > &
+    SBK_QTHELP_QLIST_QBYTEARRAY_IDX                          = 9, // QList<QByteArray >
+    SBK_QTHELP_QLIST_QVERSIONNUMBER_IDX                      = 10, // const QList<QVersionNumber > &
+    SBK_QTHELP_QMAP_QSTRING_QSTRING_IDX                      = 11, // QMap<QString,QString >
+    SBK_QTHELP_QMAP_QSTRING_QVERSIONNUMBER_IDX               = 12, // QMap<QString,QVersionNumber >
+    SBK_QTHELP_QLIST_QACTIONPTR_IDX                          = 13, // QList<QAction* >
     SBK_QTHELP_QPAIR_QSTRING_QSTRING_IDX                     = 14, // QPair<QString,QString >
     SBK_QTHELP_QLIST_QPAIR_QSTRING_QSTRING_IDX               = 15, // QList<QPair< QString,QString > >
     SBK_QTHELP_QLIST_QHELPSEARCHQUERY_IDX                    = 16, // QList<QHelpSearchQuery >
@@ -140,6 +144,8 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QCompressedHelpInfo >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QCOMPRESSEDHELPINFO_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpContentItem >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPCONTENTITEM_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpContentModel >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPCONTENTMODEL_IDX]); }
@@ -148,14 +154,17 @@ template<> inline PyTypeObject *SbkType< ::QHelpEngine >() { return reinterpret_
 template<> inline PyTypeObject *SbkType< ::QHelpEngineCore >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPENGINECORE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpFilterData >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPFILTERDATA_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpFilterEngine >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPFILTERENGINE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QHelpFilterSettingsWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPFILTERSETTINGSWIDGET_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpIndexModel >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPINDEXMODEL_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpIndexWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPINDEXWIDGET_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QHelpLink >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPLINK_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpSearchEngine >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHENGINE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpSearchQuery::FieldName >() { return SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHQUERY_FIELDNAME_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QHelpSearchQuery >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHQUERY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpSearchQueryWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHQUERYWIDGET_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpSearchResult >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHRESULT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpSearchResultWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHRESULTWIDGET_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
